@@ -83,7 +83,7 @@ function setup_ansible {
     RAW_INVENTORY=/etc/kolla/inventory
 
     # TODO(SamYaple): Move to virtualenv
-    sudo -H pip install -U "ansible>=2,<2.4" "docker-py" "python-openstackclient" "python-neutronclient" "ara" "cmd2<0.9.0"
+    sudo -H pip install -U "ansible>=2,<2.4" "docker>=2.0.0" "python-openstackclient" "python-neutronclient" "ara" "cmd2<0.9.0"
     detect_distro
 
     sudo mkdir /etc/ansible
